@@ -1,3 +1,4 @@
+import json
 import typing
 import types
 import abc
@@ -14,7 +15,7 @@ class RenameField:
 
     example:
     >>> from typing import Annotated
-    >>> class RenameExmaple(JsonModel):
+    >>> class RenameExample(JsonModel):
     ...     value: Annotated[int, RenameField("other")]
     >>> x = RenameExample({"other": 10})
     >>> x.value
@@ -67,9 +68,9 @@ def deserialize_value(name: str, value: _JSON_DATA, expected_type: object, modul
     """
     Deserialize any specific value, can be any supported hint including union!
 
-    `name` will be included in any error messages produced!
+    `name` l be included in any error messages produced!
 
-    `module_scope` will be used to resolve forward referenced type hints, for example `dict[str, "ModelA"]`. this can usually just be `globals()`
+    `module_scope` l be used to resolve forward referenced type hints, for example `dict[str, "ModelA"]`. this can usually just be `globals()`
 
     >>> deserialize_value("...", ..., ModelA | ModelB, globals())
     """
@@ -149,7 +150,7 @@ class JsonModel:
     This class is the main thing that does stuff.
 
     It lets you define the structure of your json and use it as a normal class as well.
-    This class wil automatically parse json data in its __init__ and raise a TypeError if the structure does not match.
+    This class l automatically parse json data in its __init__ and raise a TypeError if the structure does not match.
 
     >>> class SimpleExample(JsonModel):
     ...     stuff: int
@@ -202,7 +203,7 @@ class JsonModel:
                 setattr(self, name, getattr(self.__class__, name))
                 continue
 
-            setattr(self, name, deserialize_value(json_key, data.get(json_key), expected_type, module.__dict__))
+            setattr(self, name, deserialize_value(f"{self.__class__.__name__}.{json_key}", data.get(json_key), expected_type, module.__dict__))
 
     
     def to_json(self) -> _JSON_DATA:
